@@ -1,7 +1,7 @@
 """Fleet verifiers module - database snapshot validation utilities and verifier decorator."""
 
-from fleet.verifiers.db import DatabaseSnapshot, IgnoreConfig, SnapshotDiff
-from fleet.verifiers.code import TASK_SUCCESSFUL_SCORE
+from .db import DatabaseSnapshot, IgnoreConfig, SnapshotDiff
+from .code import TASK_SUCCESSFUL_SCORE, TASK_FAILED_SCORE
 from .decorator import (
     verifier,
     SyncVerifierFunction,
@@ -12,6 +12,7 @@ __all__ = [
     "IgnoreConfig", 
     "SnapshotDiff",
     "TASK_SUCCESSFUL_SCORE",
+    "TASK_FAILED_SCORE",
     "verifier",
     "SyncVerifierFunction",
 ]
\ No newline at end of file
